import { Construct } from "constructs";
import { StaticSite, StaticSiteProps } from "./StaticSite.js";
export interface ViteStaticSiteProps extends StaticSiteProps {
    /**
     * The path where code-gen should place the type definition for environment variables
     *
     * @default "src/sst-env.d.ts"
     * @example
     * ```js
     * new ViteStaticSite(stack, "Site", {
     *   typesFile: "./other/path/sst-env.d.ts",
     * })
     * ```
     */
    typesPath?: string;
}
/**
 * The `ViteStaticSite` construct is a higher level CDK construct that makes it easy to create a Vite single page app.
 *
 * @example
 *
 * Deploys a Vite app in the `path/to/src` directory.
 *
 * ```js
 * new ViteStaticSite(stack, "Site", {
 *   path: "path/to/src",
 * });
 * ```
 */
export declare class ViteStaticSite extends StaticSite {
    constructor(scope: Construct, id: string, props: ViteStaticSiteProps);
}
